;; Generated package description from engrave-faces.el  -*- no-byte-compile: t -*-
(define-package "engrave-faces" "0.3.1.0.20221004.13052" "Convert font-lock faces to other formats" '((emacs "27.1")) :commit "b4275e63fd93a33cff0d7d60fa1919181aa10ebf" :authors '(("TEC <https://git.tecosaur.net/>")) :maintainer '("TEC" . "contact@tecosaur.net") :keywords '("faces") :url "https://github.com/tecosaur/engrave-faces")
